# CosTaL: An accurate and scalabel graph-based clustering algorithm for high-dimensional single-cell data analysis

Author: Yijia Li, ..
***
#### Introduction
CosTaL use pL2knng to map k nearest neighbors and construct a kNN graph, which is later pruned using Tanimoto coefficient for a better restoration of the original similarity relationships among the cells inside the high-dimensional single-cell dataset.

CosTaL is still under development in support of all platforms. Right now, the implementation of pL2knng is only supporting the Linux system. The kNN maping on Mac and Windows platforms is temporarily using the UMAP method.
***
#### Setup
> find 
***

***

